/*
	projShadows.frag - fragment shader for shadow mapping
	
	texture_map - standard u,v map for object you're drawing
	glow_map	- map that specifies amount of glow at each texture location
	depth_map	- depth buffer from rendering scene from light's perspective
	
	use_glow	- are we actually using a glow map?
	use_shadow	- enable shadowing?
	
	diffuse, ambient, lightDir, halfVector, normal
		- standard lighting variables passed from vertex shader for per pixel lighting

	The lighting part of this shader was lifted from LightHouse3D's tutorial
	http://www.lighthouse3d.com/opengl/glsl/index.php?dirlightpix
	
	It's specifically the shadow mapping stuff that is relevent for this shader

*/

uniform sampler2D texture_map;
uniform sampler2D depth_map;
uniform bool use_glow, use_shadow;

varying vec3 normal, lightDir, halfVector;
varying vec4 diffuse, ambient;

void main()
{	
	
	gl_TexCoord[0] = gl_MultiTexCoord0;
	vec4 temp = gl_ModelViewMatrix * gl_Vertex;
	gl_TexCoord[1] = gl_TextureMatrix[1] * temp;
	
	normal = gl_NormalMatrix * gl_Normal;
	lightDir = vec3(gl_LightSource[0].position);
	halfVector = vec3(gl_LightSource[0].halfVector);

	diffuse = gl_FrontMaterial.diffuse * gl_LightSource[0].diffuse;
	ambient = gl_FrontMaterial.ambient * gl_LightSource[0].ambient;
	ambient += gl_LightModel.ambient * gl_FrontMaterial.ambient;

	gl_Position = ftransform();

} 
